Skip to main contentCrate sigs_slots
Source - Event
- Generic Event Enum for transmitting a signal
- Signal
- Generic Signal trait to be implemented by the object emitting the signals
- Slot
- Generic slot trait to be implemented by the object consuming the signals